@@ -5,7 +5,3 @@
     packageStartupMessage('On multicore systems, we suggest use of future::plan("multicore") or\n', '  future::plan("multisession") for faster post-MCMC computations.')
 }
 
-.onLoad <- function(libname, pkgname) {
-  modules <- paste0("stan_fit4", names(stanmodels), "_mod")
-  for (m in modules) loadModule(m, what = TRUE)
-}
